@@ -239,14 +239,14 @@ class Client:
             endpoint=f"/personalization/v2/players/{puuid}/playerloadout", endpoint_type="pd")
         return data
 
-    def put_player_loadout(self, puuid=None) -> dict:
+    def put_player_loadout(self, puuid=None, loadout=None) -> dict:
         '''
         playerLoadoutUpdate
         Set a player's skin/flair loadout
         '''
         puuid = self.__check_puuid(puuid)
         data = self.put(
-            endpoint=f"/personalization/v2/players/{puuid}/playerloadout", endpoint_type="pd")
+            endpoint=f"/personalization/v2/players/{puuid}/playerloadout", endpoint_type="pd", json_data=loadout)
         return data
 
     # party endpoints
